# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "BONES AND BORDERS",
]

DICT_SUB_STRUCTURES = {
    "BONES AND BORDERS":[
        'Bone',
        'Glenoid-Humerus Border'
        ]
}


# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "HREM 9.5",
    "MICRO CT",
]

DICT_SUB_STRUCTURES = {
    "HREM 9.5":[
        'AVC + LA',
        'Notochord',
        'OFT',
        'RV',
        'LV',
        'RA',
        'SFH'],
    
    "MICRO CT":['Gut',
                'Heart',
                'Liver',
                'Lungs',
                'Spleen',
                'Stomach']
}


    # "HREM":['Ao',
                # 'PA',
                # 'RV',
                # 'LV',
                # 'RA',
                # 'LA']


# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "DELTOID",
    "OTHER",
]

DICT_SUB_STRUCTURES = {
    "DELTOID":[
        'Anterior',
        'Lateral',
        'Posterior'],
    
    "OTHER":['Other']
}


# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "LARVA",
]

DICT_SUB_STRUCTURES = {
    "LARVA":[
        'Central nervous system',
        'Eye antennal discs',
        'Fat body',
        'Gonads',
        'Gut',
        'Haltere discs',
        'Leg discs',
        'Malphigian tubules', 
        'Mouth hook',
        'Muscles',
        'Salivary glands', 
        'Wings discs']
}